@@ -1,4 +1,4 @@
-package Pcore::WebDriver v0.1.1;
+package Pcore::WebDriver v0.1.2;
 
 use Pcore -dist, -const, -class, -result,
   -export => {
@@ -258,6 +258,18 @@ sub update_all ( $self, $cb = undef ) {
     return $blocking_cv ? $blocking_cv->recv : ();
 }
 
+sub new_phantomjs ( $self, @args ) {
+    return $self->new( $WD_PHANTOMJS, @args );
+}
+
+sub new_chrome ( $self, @args ) {
+    return $self->new( $WD_CHROME, @args );
+}
+
+sub new_firefox ( $self, @args ) {
+    return $self->new( $WD_FIREFOX, @args );
+}
+
 # TODO sleep
 around new => sub ( $orig, $self, $driver, %args ) {
     my $blocking_cv = defined wantarray ? AE::cv : undef;
@@ -304,7 +316,7 @@ around new => sub ( $orig, $self, $driver, %args ) {
             $self->{_proc} = $proc;
 
             # TODO
-            sleep 5;
+            sleep 1;
 
             $self->new_session(
                 sub ($res) {
@@ -395,7 +407,10 @@ sub new_session ( $self, $cb = undef ) {
                 takesScreenshot   => \1,
                 handlesAlerts     => \1,
                 chromeOptions     => {
-                    args => ['start-maximized'],    # 'no-sandbox', 'user-data-dir'
+                    args  => ['start-maximized'],    # 'no-sandbox', 'user-data-dir'
+                    prefs => {                       # list of options can be found in Preferences file in chrome profile
+                        'profile.default_content_setting_values.notifications' => 2,
+                    },
                 },
                 'moz:firefoxOptions' => {
                     binary => '',
@@ -1015,15 +1030,15 @@ JS
 ## |======+======================+================================================================================================================|
 ## |    3 | 153, 192, 231        | ErrorHandling::RequireCheckingReturnValueOfEval - Return value of eval not tested                              |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 338                  | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
+## |    3 | 350                  | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 341                  | Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               |
+## |    3 | 353                  | Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 419, 698, 704, 710,  | ControlStructures::ProhibitYadaOperator - yada operator (...) used                                             |
-## |      | 716, 722, 731, 737,  |                                                                                                                |
-## |      | 743, 749             |                                                                                                                |
+## |    3 | 434, 713, 719, 725,  | ControlStructures::ProhibitYadaOperator - yada operator (...) used                                             |
+## |      | 731, 737, 746, 752,  |                                                                                                                |
+## |      | 758, 764             |                                                                                                                |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 401                  | ValuesAndExpressions::ProhibitEmptyQuotes - Quotes used with a string containing no non-whitespace characters  |
+## |    2 | 416                  | ValuesAndExpressions::ProhibitEmptyQuotes - Quotes used with a string containing no non-whitespace characters  |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
